"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_paymentresponse import DtoPaymentResponse, DtoPaymentResponseTypedDict
from .webhookeventname import WebhookEventName
from flexprice.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class WebhookDtoPaymentWebhookPayloadTypedDict(TypedDict):
    event_type: NotRequired[WebhookEventName]
    payment: NotRequired[DtoPaymentResponseTypedDict]


class WebhookDtoPaymentWebhookPayload(BaseModel):
    event_type: Optional[WebhookEventName] = None

    payment: Optional[DtoPaymentResponse] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["event_type", "payment"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
