"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_cloneplanrequest import DtoClonePlanRequest, DtoClonePlanRequestTypedDict
from flexprice.types import BaseModel
from flexprice.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class PostPlansIDCloneRequestTypedDict(TypedDict):
    id: str
    r"""Source Plan ID"""
    body: DtoClonePlanRequestTypedDict
    r"""Clone configuration"""


class PostPlansIDCloneRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Source Plan ID"""

    body: Annotated[
        DtoClonePlanRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""Clone configuration"""
