"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice.types import UnrecognizedStr
from typing import Literal, Union


ScheduledTaskInterval = Union[
    Literal[
        "15MIN",
        "30MIN",
        "custom",
        "hourly",
        "daily",
    ],
    UnrecognizedStr,
]
