"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .alertsettings import AlertSettings, AlertSettingsTypedDict
from flexprice.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class WebhookDtoWalletAlertInfoTypedDict(TypedDict):
    alert_settings: NotRequired[AlertSettingsTypedDict]
    alert_type: NotRequired[str]
    credit_balance: NotRequired[float]
    current_balance: NotRequired[float]
    state: NotRequired[str]


class WebhookDtoWalletAlertInfo(BaseModel):
    alert_settings: Optional[AlertSettings] = None

    alert_type: Optional[str] = None

    credit_balance: Optional[float] = None

    current_balance: Optional[float] = None

    state: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "alert_settings",
                "alert_type",
                "credit_balance",
                "current_balance",
                "state",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
