"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_updatefeaturerequest import (
    DtoUpdateFeatureRequest,
    DtoUpdateFeatureRequestTypedDict,
)
from flexprice.types import BaseModel
from flexprice.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateFeatureRequestTypedDict(TypedDict):
    id: str
    r"""Feature ID"""
    body: DtoUpdateFeatureRequestTypedDict
    r"""Feature update data"""


class UpdateFeatureRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Feature ID"""

    body: Annotated[
        DtoUpdateFeatureRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""Feature update data"""
