"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .usertype import UserType
from flexprice.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DtoCreateUserRequestTypedDict(TypedDict):
    type: UserType
    email: NotRequired[str]
    r"""Required when type is \"user\" """
    roles: NotRequired[List[str]]
    r"""Required when type is \"service_account\" """


class DtoCreateUserRequest(BaseModel):
    type: UserType

    email: Optional[str] = None
    r"""Required when type is \"user\" """

    roles: Optional[List[str]] = None
    r"""Required when type is \"service_account\" """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["email", "roles"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
