"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice.types import UnrecognizedStr
from typing import Literal, Union


CreditGrantApplicationReason = Union[
    Literal[
        "first_time_recurring_credit_grant",
        "recurring_credit_grant",
        "onetime_credit_grant",
    ],
    UnrecognizedStr,
]
